@@ -12,12 +12,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-
-from grafana_dashboards import version
+from six.moves import configparser as ConfigParser
 
 
-def prepare_args(argv):
-    cfg.CONF(
-        argv[1:], project='grafana_dashboards',
-        version=version.version_info.release_string())
+class Config(ConfigParser.ConfigParser):
+
+    def __init__(self):
+        ConfigParser.ConfigParser.__init__(self)
+        # Add [cache] section
+        self.add_section('cache')
+        self.set('cache', 'cachedir', '~/.cache/grafyaml')
+        self.set('cache', 'enabled', 'true')
+        # Add [grafana] section
+        self.add_section('grafana')
+        self.set('grafana', 'apikey', '')
+        self.set('grafana', 'url', 'http://localhost:8080')
